@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -74,14 +74,11 @@ function openNewWindowWith(href, sourceURL, postData)
  */
 function urlSecurityCheck(url, sourceURL)
 {
-  var sourceURI = makeURI(sourceURL);
-  var destURI = makeURI(url);
-
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
   try {
-    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(sourceURL, url, nsIScriptSecurityManager.STANDARD);
   } catch (e) {
     throw "Load of " + url + " from " + sourceURL + " denied.";
   }
@@ -249,8 +246,8 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
       charset = aDocument.characterSet;
     else if (aReferrer)
       charset = aReferrer.originCharset;
-    initFileInfo(fileInfo, aURL, charset, aDocument,
-                 aContentType, aContentDisposition);
+    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition,
+                 charset);
     var fpParams = {
       fpTitleKey: aFilePickerTitleKey,
       isDocument: isDocument,
@@ -390,16 +387,18 @@ function FileInfo(aSuggestedFileName, aFileName, aFileBaseName, aFileExt, aUri)
  * for confirmation in the file picker dialog.
  * @param aFI A FileInfo structure into which we'll put the results of this method.
  * @param aURL The String representation of the URL of the document being saved
- * @param aURLCharset The charset of aURL.
  * @param aDocument The document to be saved
  * @param aContentType The content type we're saving, if it could be
  *        determined by the caller.
  * @param aContentDisposition The content-disposition header for the object
  *        we're saving, if it could be determined by the caller.
+ * @param aURLCharset The charset of aURL.
  */
-function initFileInfo(aFI, aURL, aURLCharset, aDocument,
-                      aContentType, aContentDisposition)
+function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition,
+                      aURLCharset)
 {
+  if (!aURLCharset && aDocument && aDocument.characterSet)
+    aURLCharset = aDocument.characterSet;
   try {
     // Get an nsIURI object from aURL if possible:
     try {
@@ -458,9 +457,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 505 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 504 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 508 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 507 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -848,7 +847,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 899 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 898 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
